bayespy.inference.vmp.nodes.multinomial.MultinomialDistribution.compute_phi_from_parents
========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. automethod:: MultinomialDistribution.compute_phi_from_parents